==> testcafe-0.0.16.tgz: package/lib/cli/index.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var runTests = function () {
    var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(argParser) {
        var opts, port1, port2, testCafe, remoteBrowsers, browsers, runner, failed;
        return _regenerator2.default.wrap(function _callee$(_context) {
            while (1) {
                switch (_context.prev = _context.next) {
                    case 0:
                        opts = argParser.opts;
                        port1 = opts.ports && opts.ports[0];
                        port2 = opts.ports && opts.ports[1];


                        _log2.default.showSpinner();

                        _context.next = 6;
                        return (0, _2.default)(opts.hostname, port1, port2);

                    case 6:
                        testCafe = _context.sent;
                        _context.next = 9;
                        return (0, _remotesWizard2.default)(testCafe, argParser.remoteCount, opts.qrCode);

                    case 9:
                        remoteBrowsers = _context.sent;
                        browsers = argParser.browsers.concat(remoteBrowsers);
                        runner = testCafe.createRunner();


                        runner.src(argParser.src).browsers(browsers).reporter(opts.reporter).filter(argParser.filter).screenshots(opts.screenshots, opts.screenshotsOnFails);

                        runner.once('done-bootstrapping', function () {
                            return _log2.default.hideSpinner();
                        });

                        _context.next = 16;
                        return runner.run({
                            skipJsErrors: opts.skipJsErrors,
                            quarantineMode: opts.quarantineMode
                        });

                    case 16:
                        failed = _context.sent;


                        exit(failed);

                    case 18:
                    case 'end':
                        return _context.stop();
                }
            }
        }, _callee, this);
    }));
    return function runTests(_x) {
        return ref.apply(this, arguments);
    };
}();

var listBrowsers = function () {
    var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
        var installations, aliases;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
            while (1) {
                switch (_context2.prev = _context2.next) {
                    case 0:
                        _context2.next = 2;
                        return (0, _testcafeBrowserNatives.getInstallations)();

                    case 2:
                        installations = _context2.sent;
                        aliases = (0, _keys2.default)(installations);


                        console.log(aliases.join('\n'));
                        exit(0);

                    case 6:
                    case 'end':
                        return _context2.stop();
                }
            }
        }, _callee2, this);
    }));
    return function listBrowsers() {
        return ref.apply(this, arguments);
    };
}();

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _resolveCwd = require('resolve-cwd');

var _resolveCwd2 = _interopRequireDefault(_resolveCwd);

var _testcafeBrowserNatives = require('testcafe-browser-natives');

var _runtime = require('../errors/runtime');

var _argumentParser = require('./argument-parser');

var _argumentParser2 = _interopRequireDefault(_argumentParser);

var _log = require('./log');

var _log2 = _interopRequireDefault(_log);

var _remotesWizard = require('./remotes-wizard');

var _remotesWizard2 = _interopRequireDefault(_remotesWizard);

var _ = require('../');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function exit(code) {
    _log2.default.hideSpinner();

    // NOTE: give a process time to flush the output.
    // It's necessary in some environments.
    setTimeout(function () {
        return process.exit(code);
    }, 0);
}

function error(err) {
    _log2.default.hideSpinner();

    var message = null;

    // HACK: workaround for the `instanceof` problem
    // (see: http://stackoverflow.com/questions/33870684/why-doesnt-instanceof-work-on-instances-of-error-subclasses-under-babel-node)
    if (err.constructor === _runtime.GeneralError) message = err.message;else if (err.constructor === _runtime.APIError) message = err.coloredStack;else message = err.stack;

    _log2.default.write(_chalk2.default.red('ERROR ') + message + '\n');
    _log2.default.write(_chalk2.default.gray('Type "testcafe -h" for help.'));

    exit(1);
}

function useLocalInstallation() {
    var local = (0, _resolveCwd2.default)('testcafe/lib/cli');

    if (local && local !== __filename) {
        require(local);
        return true;
    }

    return false;
}

(function () {
    var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
        var argParser;
        return _regenerator2.default.wrap(function _callee3$(_context3) {
            while (1) {
                switch (_context3.prev = _context3.next) {
                    case 0:
                        if (!useLocalInstallation()) {
                            _context3.next = 2;
                            break;
                        }

                        return _context3.abrupt('return');

                    case 2:
                        _context3.prev = 2;
                        argParser = new _argumentParser2.default();
                        _context3.next = 6;
                        return argParser.parse(process.argv);

                    case 6:
                        if (!argParser.opts.listBrowsers) {
                            _context3.next = 10;
                            break;
                        }

                        listBrowsers();
                        _context3.next = 12;
                        break;

                    case 10:
                        _context3.next = 12;
                        return runTests(argParser);

                    case 12:
                        _context3.next = 17;
                        break;

                    case 14:
                        _context3.prev = 14;
                        _context3.t0 = _context3['catch'](2);

                        error(_context3.t0);

                    case 17:
                    case 'end':
                        return _context3.stop();
                }
            }
        }, _callee3, this, [[2, 14]]);
    }));

    function cli() {
        return ref.apply(this, arguments);
    }

    return cli;
})()();

==> testcafe-0.0.21.tgz: package/lib/cli/index.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var runTests = function () {
    var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(argParser) {
        var opts, port1, port2, testCafe, remoteBrowsers, browsers, runner, failed;
        return _regenerator2.default.wrap(function _callee$(_context) {
            while (1) {
                switch (_context.prev = _context.next) {
                    case 0:
                        opts = argParser.opts;
                        port1 = opts.ports && opts.ports[0];
                        port2 = opts.ports && opts.ports[1];


                        _log2.default.showSpinner();

                        _context.next = 6;
                        return (0, _2.default)(opts.hostname, port1, port2);

                    case 6:
                        testCafe = _context.sent;
                        _context.next = 9;
                        return (0, _remotesWizard2.default)(testCafe, argParser.remoteCount, opts.qrCode);

                    case 9:
                        remoteBrowsers = _context.sent;
                        browsers = argParser.browsers.concat(remoteBrowsers);
                        runner = testCafe.createRunner();


                        runner.src(argParser.src).browsers(browsers).reporter(opts.reporter).filter(argParser.filter).screenshots(opts.screenshots, opts.screenshotsOnFails);

                        runner.once('done-bootstrapping', function () {
                            return _log2.default.hideSpinner();
                        });

                        _context.next = 16;
                        return runner.run({
                            skipJsErrors: opts.skipJsErrors,
                            quarantineMode: opts.quarantineMode,
                            selectorTimeout: opts.selectorTimeout
                        });

                    case 16:
                        failed = _context.sent;


                        exit(failed);

                    case 18:
                    case 'end':
                        return _context.stop();
                }
            }
        }, _callee, this);
    }));
    return function runTests(_x) {
        return ref.apply(this, arguments);
    };
}();

var listBrowsers = function () {
    var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
        var installations, aliases;
        return _regenerator2.default.wrap(function _callee2$(_context2) {
            while (1) {
                switch (_context2.prev = _context2.next) {
                    case 0:
                        _context2.next = 2;
                        return (0, _testcafeBrowserNatives.getInstallations)();

                    case 2:
                        installations = _context2.sent;
                        aliases = (0, _keys2.default)(installations);


                        console.log(aliases.join('\n'));
                        exit(0);

                    case 6:
                    case 'end':
                        return _context2.stop();
                }
            }
        }, _callee2, this);
    }));
    return function listBrowsers() {
        return ref.apply(this, arguments);
    };
}();

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _resolveCwd = require('resolve-cwd');

var _resolveCwd2 = _interopRequireDefault(_resolveCwd);

var _testcafeBrowserNatives = require('testcafe-browser-natives');

var _runtime = require('../errors/runtime');

var _argumentParser = require('./argument-parser');

var _argumentParser2 = _interopRequireDefault(_argumentParser);

var _log = require('./log');

var _log2 = _interopRequireDefault(_log);

var _remotesWizard = require('./remotes-wizard');

var _remotesWizard2 = _interopRequireDefault(_remotesWizard);

var _ = require('../');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function exit(code) {
    _log2.default.hideSpinner();

    // NOTE: give a process time to flush the output.
    // It's necessary in some environments.
    setTimeout(function () {
        return process.exit(code);
    }, 0);
}

function error(err) {
    _log2.default.hideSpinner();

    var message = null;

    // HACK: workaround for the `instanceof` problem
    // (see: http://stackoverflow.com/questions/33870684/why-doesnt-instanceof-work-on-instances-of-error-subclasses-under-babel-node)
    if (err.constructor === _runtime.GeneralError) message = err.message;else if (err.constructor === _runtime.APIError) message = err.coloredStack;else message = err.stack;

    _log2.default.write(_chalk2.default.red('ERROR ') + message + '\n');
    _log2.default.write(_chalk2.default.gray('Type "testcafe -h" for help.'));

    exit(1);
}

function useLocalInstallation() {
    var local = (0, _resolveCwd2.default)('testcafe/lib/cli');

    if (local && local !== __filename) {
        require(local);
        return true;
    }

    return false;
}

(function () {
    var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
        var argParser;
        return _regenerator2.default.wrap(function _callee3$(_context3) {
            while (1) {
                switch (_context3.prev = _context3.next) {
                    case 0:
                        if (!useLocalInstallation()) {
                            _context3.next = 2;
                            break;
                        }

                        return _context3.abrupt('return');

                    case 2:
                        _context3.prev = 2;
                        argParser = new _argumentParser2.default();
                        _context3.next = 6;
                        return argParser.parse(process.argv);

                    case 6:
                        if (!argParser.opts.listBrowsers) {
                            _context3.next = 10;
                            break;
                        }

                        listBrowsers();
                        _context3.next = 12;
                        break;

                    case 10:
                        _context3.next = 12;
                        return runTests(argParser);

                    case 12:
                        _context3.next = 17;
                        break;

                    case 14:
                        _context3.prev = 14;
                        _context3.t0 = _context3['catch'](2);

                        error(_context3.t0);

                    case 17:
                    case 'end':
                        return _context3.stop();
                }
            }
        }, _callee3, this, [[2, 14]]);
    }));

    function cli() {
        return ref.apply(this, arguments);
    }

    return cli;
})()();
